Introduction — mujpy 0.1 documentation

# Introduction

Welcome to mujpy, the [[jupyter notebook|<http://jupyter.readthedocs.io/en/latest/install.html>]] interface for muon spin spectroscopy analysis. This suite is based loosely on the general layout of the Matlab mulab<http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.Mulab>_ interface and on contamination of ideas with `musrfit<http://lmu.web.psi.ch/musrfit/technical/main.html>_’ by Andreas Suter.